Learn R Programming

rgtmx (version 0.1.4)

get_report: Get status and meta data of a specific report

Description

Get status and meta data of a specific GTmetrix report.

Usage

get_report(report_id, api_key)

Arguments

report_id

ID of a GTmetrix report. (string)

api_key

An active GTmetrix API key. (string)

Value

A data.frame object that contains a GTmetrix report and its meta data.

Examples

Run this code
# NOT RUN {
output_table <- get_report(
                           test_id = "REPORT_ID",
                           api_key = "API_KEY"
                         )
# }

Run the code above in your browser using DataLab